@@ -52,33 +52,13 @@
 
 	summary.sitar <- function (object, adjustSigma = TRUE, verbose = FALSE, ...)
 {
-    class(object) <- class(object)[-1]
+#	save age at peak velocity
+	  apv <- makess(getCovariate(object), fitted(object, level=0))$apv
+
+	  class(object) <- class(object)[-1]
     object <- summary(object, adjustSigma=adjustSigma, verbose=verbose, ...)
 
-#	adjust x and y for random effects a, b and c
-	random <- as.character(object$call$random)[2]
-	mcall <- object$call.sitar
-	data <- eval(mcall$data)
-	subset <- eval(mcall$subset, data)
-	if (!is.null(subset)) data <- data[subset,]
-	x <- eval(mcall$x, data)
-	y <- eval(mcall$y, data)
-	id <- eval(mcall$id, data)
-	nf <- length(fitted(object))
-	if (nf != length(y)) stop(paste('model (length=', nf, ') incompatible with data (rows=', length(y), ')', sep=''))
-	xoffset <- object$xoffset
-	if (is.null(xoffset)) xoffset <- 0
-	if (!is.na(fixef(object)['b'])) xoffset <- xoffset + fixef(object)['b']
-	x.adj <- x - xoffset
-	if (grepl('b', random)) x.adj <- x.adj - ranef(object)[factor(id),'b']
-	if (grepl('c', random)) x.adj <- x.adj * exp(ranef(object)[factor(id),'c'])
-	object$x.adj <- x.adj + xoffset
-	y.adj <- y
-	if (grepl('a', random)) y.adj <- y.adj - ranef(object)[factor(id),'a']
-	object$y.adj <- y.adj
-
-#	save age at peak velocity
-	object$apv <- makess(x, fitted(object, level=0))$apv
+    object$apv <- apv
 
     class(object) <- c("summary.sitar", class(object))
     object
@@ -379,7 +359,7 @@
 
 #	update value of bstart to minimise b-c correlation
 	bupdate <- function(x) {
-	cov <- as.matrix(x$modelStruct[[1]][[1]])
+	cov <- getVarCov(x)
 	fixef(x)['b'] + cov[2,3] / cov[3,3]
 	}
 
@@ -661,6 +641,5 @@ yaxsd <- function(usr=par()$usr[3:4]) {
 ################
 
 #	plot.sitar
-#		back-transform transformed x / y scales
 #		add acceleration curve option
 #		improve ylim for dau plots
